SystemOrganization addCategory: 'tODE-GemTools'!

TOView subclass: #TOObjectLog
	instanceVariableNames: 'summaryReport'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'tODE-GemTools'!

!TOObjectLog methodsFor: 'summary' stamp: 'dkh 05/21/2011 08:18'!
createSummaryReport
	| labels summaryColumns |
	labels := self labels.
	summaryColumns := (OrderedCollection new)
		add: ((WAReportColumn
			renderBlock: [ :each :html | 
				html text: (labels at: each key) ]
			title: 'name')
			sortBlock: nil);
		add: ((WAReportColumn
			selector: #key title: 'priority')
			sortBlock: [:a :b | a < b ]);
		add: ((WAReportColumn
			selector: #value title: 'count')
			sortBlock: [:a :b | a < b ]);
		add: ((WAReportColumn
			renderBlock: [ :each :html | 
				each value == 0
					ifTrue: [ html text: '-' ]
					ifFalse: [
						html anchor
							callback: [ self deleteAllAtPriority: each ];
							title: 'delete';
							with: 'all ', (labels at: each key)] ]
			title: 'delete')
			sortBlock: nil);
		yourself.
	summaryReport := WAObjectLogTableReport new
		rows: self objectLogSummary;
		columns: summaryColumns;
		rowPeriod: 1;
		yourself.
	^summaryReport
	
! !

!TOObjectLog methodsFor: 'private' stamp: 'dkh 05/21/2011 08:19'!
deleteAllAtPriority: aSummaryEntry

	| priority log |
	priority := aSummaryEntry key.
	log := self getObjectLogEntries: true.
	(log select: [:ea | ea priority == priority ]) do: [:ea |  log remove: ea ifAbsent: []].! !

!TOObjectLog methodsFor: 'accessing' stamp: 'dkh 05/21/2011 08:16'!
getObjectLogEntries: shouldLock

	shouldLock 
		ifTrue: [
			System writeLock: ObjectLogEntry objectQueue
				ifDenied: [ 
					WARetryHttpRequest signal: 'ObjectLogEntry objectQueue lock denied'.
					"does not return" ]
				ifChanged: [ 
					System addToCommitOrAbortReleaseLocksSet: ObjectLogEntry objectQueue.
					WARetryHttpRequest signal: 'ObjectLogEntry objectQueue lock dirty'.
					"does not return" ].
			System addToCommitOrAbortReleaseLocksSet: ObjectLogEntry objectQueue].
	^ObjectLogEntry objectLog! !

!TOObjectLog methodsFor: 'accessing' stamp: 'dkh 05/21/2011 08:09'!
labels

	^#('fatal' 'error' 'warn' 'info' 'debug' 'trace' 'transcript').
! !

!TOObjectLog methodsFor: 'accessing' stamp: 'dkh 05/21/2011 08:17'!
objectLog

	^self getObjectLogEntries: false! !

!TOObjectLog methodsFor: 'summary' stamp: 'dkh 05/21/2011 08:12'!
objectLogSummary

	| sums summary |
	sums := Dictionary new.
	1 to: self labels size do: [:i | sums at: i put: 0 ].
	self objectLog do: [:ea | | tally |
		tally := sums at: ea priority.
		sums at: ea priority put: (tally + 1)].
	summary := Array new: self labels size.
	1 to: self labels size do: [:i| summary at: i put: (sums associationAt: i) ].
	^summary! !

!TOObjectLog methodsFor: 'rendering' stamp: 'dkh 05/21/2011 07:55'!
renderDebugOn: html spec: aTOTabSpec main: main

	self renderEntry: ObjectLogEntry debug on: html spec: aTOTabSpec main: main! !

!TOObjectLog methodsFor: 'rendering' stamp: 'dkh 05/21/2011 08:06'!
renderEntry: priority on: html spec: aTOTabSpec main: main

	html text: 'Under construction'.
	self objectLog select: [:each | each priority = priority ]! !

!TOObjectLog methodsFor: 'rendering' stamp: 'dkh 05/21/2011 07:55'!
renderErrorOn: html spec: aTOTabSpec main: main

	self renderEntry: ObjectLogEntry error on: html spec: aTOTabSpec main: main! !

!TOObjectLog methodsFor: 'rendering' stamp: 'dkh 05/21/2011 07:55'!
renderFatalOn: html spec: aTOTabSpec main: main

	self renderEntry: ObjectLogEntry fatal on: html spec: aTOTabSpec main: main! !

!TOObjectLog methodsFor: 'rendering' stamp: 'dkh 05/21/2011 07:55'!
renderInfoOn: html spec: aTOTabSpec main: main

	self renderEntry: ObjectLogEntry info on: html spec: aTOTabSpec main: main! !

!TOObjectLog methodsFor: 'rendering' stamp: 'dkh 05/21/2011 08:11'!
renderSummaryOn: html spec: aTOTabSpec main: main

	self summaryReport rows: self objectLogSummary.
	html render: self summaryReport! !

!TOObjectLog methodsFor: 'rendering' stamp: 'dkh 05/21/2011 07:56'!
renderTraceOn: html spec: aTOTabSpec main: main

	self renderEntry: ObjectLogEntry trace on: html spec: aTOTabSpec main: main! !

!TOObjectLog methodsFor: 'rendering' stamp: 'dkh 05/21/2011 07:56'!
renderTranscriptOn: html spec: aTOTabSpec main: main

	(self objectLog select: [:each | each priority = ObjectLogEntry transcript ]) do: [:entry |
		html text: entry object asString.
		html break ].! !

!TOObjectLog methodsFor: 'rendering' stamp: 'dkh 05/21/2011 08:05'!
renderWarnOn: html spec: aTOTabSpec main: main

	self renderEntry: ObjectLogEntry warn on: html spec: aTOTabSpec main: main! !

!TOObjectLog methodsFor: 'summary' stamp: 'dkh 05/21/2011 08:18'!
summaryReport

	summaryReport ifNil: [ summaryReport := self createSummaryReport ].
	^summaryReport! !

!TOObjectLog methodsFor: 'accessing' stamp: 'dkh 05/21/2011 07:38'!
tODEFrameClassFor: aSession

	^TOObjectLogFrame! !

TOObjectFrame subclass: #TOObjectLogFrame
	instanceVariableNames: 'objectLogSpec useBasicFrame'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'tODE-GemTools'!

!TOObjectLogFrame methodsFor: 'accessing' stamp: 'dkh 05/21/2011 08:04'!
calculateObjectLogSpec

	^{
		self tabSpec: #summary renderSelector: #renderSummaryOn:spec:main:.
		self tabSpec: #fatal renderSelector: #renderFatalOn:spec:main:.
		self tabSpec: #error renderSelector: #renderErrorOn:spec:main:.
		self tabSpec: #warn renderSelector: #renderWarnOn:spec:main:.
		self tabSpec: #info renderSelector: #renderInfoOn:spec:main:.
		self tabSpec: #debug renderSelector: #renderDebugOn:spec:main:.
		self tabSpec: #trace renderSelector: #renderTraceOn:spec:main:.
		self tabSpec: #transcript renderSelector: #renderTranscriptOn:spec:main:.
	}! !

!TOObjectLogFrame methodsFor: 'accessing' stamp: 'dkh 05/21/2011 07:46'!
centerTabSpec

	self useBasicFrame ifTrue: [ ^super centerTabSpec ].
	^self objectLogSpec! !

!TOObjectLogFrame methodsFor: 'accessing' stamp: 'dkh 05/21/2011 07:46'!
objectLogSpec

	objectLogSpec ifNil: [ objectLogSpec := self calculateObjectLogSpec ].
	^objectLogSpec! !

!TOObjectLogFrame methodsFor: 'accessing' stamp: 'dkh 05/21/2011 07:59'!
tabSpec: id renderSelector: renderSelector

	^(TOTabSpec new)
		id: id;
		rendererClass: TOObjectLog;
		receiver: self object;
		label: id asString;
		order: 0;
		group: 'object log';
		renderSelector: renderSelector! !

!TOObjectLogFrame methodsFor: 'accessing' stamp: 'dkh 05/21/2011 07:39'!
useBasicFrame

	useBasicFrame ifNil: [ useBasicFrame := false ].
	^useBasicFrame! !

TOHome subclass: #TOGemToolsHome
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'tODE-GemTools'!

!TOGemToolsHome classSide methodsFor: 'class initialization' stamp: 'dkh 05/21/2011 07:18'!
initialize
	"self initialize"
	
	self select! !

!TOGemToolsHome methodsFor: 'rendering' stamp: 'dkh 05/21/2011 07:19'!
renderGemToolsOn: html main: main

	html strong: 'Workspaces: '.
	self renderWorkspacesOn: html main: main.
	html break.
	html strong: 'Tools: '.
	self renderToolsOn: html main: main
! !

!TOGemToolsHome methodsFor: 'rendering' stamp: 'dkh 05/21/2011 07:18'!
renderInspectorContentOn: html for: aTOInspector main: main
	aTOInspector getMembers.
	aTOInspector basicInspect
		ifTrue: [ ^ aTOInspector renderStandardContentOn: html main: main ].
	html strong: 'tOde operations:'.
	html unorderedList: [self renderControlsOn: html main: main].
	html strong: 'GemTools:'.
	html unorderedList: [self renderGemToolsOn: html main: main].
	html strong: 'Bookmarks:'.
	html unorderedList: [self renderBookmarksOn: html main: main].
	html horizontalRule.
	html horizontalRule.
	aTOInspector renderBasicToggleOn: html main: main.
! !

!TOGemToolsHome methodsFor: 'rendering' stamp: 'dkh 05/21/2011 08:14'!
renderToolsOn: html main: main

	self
		renderButton: [ :s | 
			self currentSession push: TOObjectLog new selecting: #summary.
			main updateCenterSideHistory: s ]
		label: 'Object Log'
		on: html.
	html space.
	self
		renderButton: [ :s | | sbni sentNotImplemented |
			sbni := SentButNotImplementedTest new.
			(sentNotImplemented := sbni sentButNotImplemented) removeAllPresent: sbni specialCases.
			self currentSession push: sentNotImplemented selecting: #inspect.
			main updateCenterSideHistory: s ]
		label: 'Sent not Implemented'
		on: html.
	html space.
	self
		renderButton: [ :s | | us undefined dict |
			us := UndefinedSymbolsTest new.
			us cleanUndefinedSymbols.
			(undefined := UndefinedSymbols keys) removeAllPresent: us specialCases.
			dict := Dictionary new.
			undefined do: [:undef | dict at: undef put: (UndefinedSymbols at: undef) ].
			self currentSession push: dict selecting: #inspect.
			main updateCenterSideHistory: s ]
		label: 'Undefined Symbols'
		on: html.
! !

!TOGemToolsHome methodsFor: 'rendering' stamp: 'dkh 05/21/2011 07:19'!
renderWorkspacesOn: html main: main
	| inspector workspaces |
	workspaces := OrderedCollection new.
	(UserGlobals at: #SqueakWorkspace) keysAndValuesDo: [:name :contents | | fr ws |
		workspaces add: name->contents.
		"predefine the frames for the workspace string and set the contents of the workspace tab"
		fr := self currentSession findFrameFor: contents.
		(ws := fr rendererForCenterTab: #workspace) ifNotNil: [
			ws contents: contents ]].
	(workspaces sorted: [:a :b | a key <= b key ]) do: [:assoc |
		self
			renderButton: [ :s | | bms |
				self currentSession push: assoc value selecting: #workspace.
				main updateCenterSideHistory: s ]
			label: assoc key
			on: html.
		html space ]! !
TOGemToolsHome initialize!
